@@ -1,132 +1,150 @@
 var annotated_dup =
 [
-    [ "buffer", "structbuffer.html", "structbuffer" ],
-    [ "client", "structclient.html", "structclient" ],
-    [ "client_data", "structclient__data.html", "structclient__data" ],
-    [ "control", "structcontrol.html", "structcontrol" ],
-    [ "data", "structdata.html", "structdata" ],
-    [ "default_node", "structdefault__node.html", "structdefault__node" ],
-    [ "device", "structdevice.html", "structdevice" ],
-    [ "endpoint", "structendpoint.html", "structendpoint" ],
-    [ "endpoint_link", "structendpoint__link.html", "structendpoint__link" ],
-    [ "error_data", "structerror__data.html", "structerror__data" ],
-    [ "factory_data", "structfactory__data.html", "structfactory__data" ],
-    [ "filter", "structfilter.html", "structfilter" ],
-    [ "find_data", "structfind__data.html", "structfind__data" ],
-    [ "find_node", "structfind__node.html", "structfind__node" ],
-    [ "find_port", "structfind__port.html", "structfind__port" ],
-    [ "graph", "structgraph.html", "structgraph" ],
-    [ "graph_hndl", "structgraph__hndl.html", "structgraph__hndl" ],
-    [ "graph_port", "structgraph__port.html", "structgraph__port" ],
-    [ "handle", "structhandle.html", "structhandle" ],
-    [ "impl", "structimpl.html", "structimpl" ],
-    [ "item", "structitem.html", "structitem" ],
-    [ "ladspa_descriptor", "structladspa__descriptor.html", "structladspa__descriptor" ],
-    [ "ladspa_handle", "structladspa__handle.html", "structladspa__handle" ],
-    [ "link", "structlink.html", "structlink" ],
-    [ "link_data", "structlink__data.html", "structlink__data" ],
-    [ "log_ctx", "structlog__ctx.html", "structlog__ctx" ],
-    [ "mapping", "structmapping.html", "structmapping" ],
-    [ "memblock", "structmemblock.html", "structmemblock" ],
-    [ "memmap", "structmemmap.html", "structmemmap" ],
-    [ "mempool", "structmempool.html", "structmempool" ],
-    [ "metadata", "structmetadata.html", "structmetadata" ],
-    [ "module_roc_sink_data", "structmodule__roc__sink__data.html", "structmodule__roc__sink__data" ],
-    [ "module_roc_source_data", "structmodule__roc__source__data.html", "structmodule__roc__source__data" ],
-    [ "node", "structnode.html", "structnode" ],
-    [ "node_data", "structnode__data.html", "structnode__data" ],
-    [ "object_data", "structobject__data.html", "structobject__data" ],
-    [ "object_entry", "structobject__entry.html", "structobject__entry" ],
-    [ "object_info", "structobject__info.html", "structobject__info" ],
-    [ "param", "structparam.html", "structparam" ],
-    [ "param_filter", "structparam__filter.html", "structparam__filter" ],
-    [ "plugin", "structplugin.html", "structplugin" ],
-    [ "port", "structport.html", "structport" ],
-    [ "profile", "structprofile.html", "structprofile" ],
-    [ "protocol_data", "structprotocol__data.html", "structprotocol__data" ],
+    [ "itimerspec", "structitimerspec.html", null ],
     [ "pw_array", "structpw__array.html", "structpw__array" ],
     [ "pw_buffer", "structpw__buffer.html", "structpw__buffer" ],
     [ "pw_buffers", "structpw__buffers.html", "structpw__buffers" ],
+    [ "pw_client", "structpw__client.html", null ],
+    [ "pw_client_endpoint", "structpw__client__endpoint.html", null ],
+    [ "pw_client_endpoint_events", "structpw__client__endpoint__events.html", "structpw__client__endpoint__events" ],
+    [ "pw_client_endpoint_methods", "structpw__client__endpoint__methods.html", "structpw__client__endpoint__methods" ],
     [ "pw_client_events", "structpw__client__events.html", "structpw__client__events" ],
     [ "pw_client_info", "structpw__client__info.html", "structpw__client__info" ],
     [ "pw_client_methods", "structpw__client__methods.html", "structpw__client__methods" ],
+    [ "pw_client_node", "structpw__client__node.html", null ],
+    [ "pw_client_node_buffer", "structpw__client__node__buffer.html", "structpw__client__node__buffer" ],
+    [ "pw_client_node_events", "structpw__client__node__events.html", "structpw__client__node__events" ],
+    [ "pw_client_node_methods", "structpw__client__node__methods.html", "structpw__client__node__methods" ],
+    [ "pw_client_session", "structpw__client__session.html", null ],
+    [ "pw_client_session_events", "structpw__client__session__events.html", "structpw__client__session__events" ],
+    [ "pw_client_session_methods", "structpw__client__session__methods.html", "structpw__client__session__methods" ],
+    [ "pw_context", "structpw__context.html", null ],
     [ "pw_context_events", "structpw__context__events.html", "structpw__context__events" ],
+    [ "pw_control", "structpw__control.html", null ],
     [ "pw_control_events", "structpw__control__events.html", "structpw__control__events" ],
+    [ "pw_core", "structpw__core.html", null ],
     [ "pw_core_events", "structpw__core__events.html", "structpw__core__events" ],
     [ "pw_core_info", "structpw__core__info.html", "structpw__core__info" ],
     [ "pw_core_methods", "structpw__core__methods.html", "structpw__core__methods" ],
+    [ "pw_data_loop", "structpw__data__loop.html", null ],
     [ "pw_data_loop_events", "structpw__data__loop__events.html", "structpw__data__loop__events" ],
+    [ "pw_device", "structpw__device.html", null ],
     [ "pw_device_events", "structpw__device__events.html", "structpw__device__events" ],
     [ "pw_device_info", "structpw__device__info.html", "structpw__device__info" ],
     [ "pw_device_methods", "structpw__device__methods.html", "structpw__device__methods" ],
+    [ "pw_endpoint", "structpw__endpoint.html", null ],
+    [ "pw_endpoint_events", "structpw__endpoint__events.html", "structpw__endpoint__events" ],
+    [ "pw_endpoint_info", "structpw__endpoint__info.html", "structpw__endpoint__info" ],
+    [ "pw_endpoint_link", "structpw__endpoint__link.html", null ],
+    [ "pw_endpoint_link_events", "structpw__endpoint__link__events.html", "structpw__endpoint__link__events" ],
+    [ "pw_endpoint_link_info", "structpw__endpoint__link__info.html", "structpw__endpoint__link__info" ],
+    [ "pw_endpoint_link_methods", "structpw__endpoint__link__methods.html", "structpw__endpoint__link__methods" ],
+    [ "pw_endpoint_methods", "structpw__endpoint__methods.html", "structpw__endpoint__methods" ],
+    [ "pw_endpoint_stream", "structpw__endpoint__stream.html", null ],
+    [ "pw_endpoint_stream_events", "structpw__endpoint__stream__events.html", "structpw__endpoint__stream__events" ],
+    [ "pw_endpoint_stream_info", "structpw__endpoint__stream__info.html", "structpw__endpoint__stream__info" ],
+    [ "pw_endpoint_stream_methods", "structpw__endpoint__stream__methods.html", "structpw__endpoint__stream__methods" ],
     [ "pw_export_type", "structpw__export__type.html", "structpw__export__type" ],
+    [ "pw_factory", "structpw__factory.html", null ],
     [ "pw_factory_events", "structpw__factory__events.html", "structpw__factory__events" ],
     [ "pw_factory_info", "structpw__factory__info.html", "structpw__factory__info" ],
     [ "pw_factory_methods", "structpw__factory__methods.html", "structpw__factory__methods" ],
+    [ "pw_filter", "structpw__filter.html", null ],
     [ "pw_filter_events", "structpw__filter__events.html", "structpw__filter__events" ],
+    [ "pw_global", "structpw__global.html", null ],
     [ "pw_global_events", "structpw__global__events.html", "structpw__global__events" ],
+    [ "pw_impl_client", "structpw__impl__client.html", null ],
     [ "pw_impl_client_events", "structpw__impl__client__events.html", "structpw__impl__client__events" ],
+    [ "pw_impl_core", "structpw__impl__core.html", null ],
     [ "pw_impl_core_events", "structpw__impl__core__events.html", "structpw__impl__core__events" ],
+    [ "pw_impl_device", "structpw__impl__device.html", null ],
     [ "pw_impl_device_events", "structpw__impl__device__events.html", "structpw__impl__device__events" ],
+    [ "pw_impl_factory", "structpw__impl__factory.html", null ],
     [ "pw_impl_factory_events", "structpw__impl__factory__events.html", "structpw__impl__factory__events" ],
     [ "pw_impl_factory_implementation", "structpw__impl__factory__implementation.html", "structpw__impl__factory__implementation" ],
+    [ "pw_impl_link", "structpw__impl__link.html", null ],
     [ "pw_impl_link_events", "structpw__impl__link__events.html", "structpw__impl__link__events" ],
+    [ "pw_impl_metadata", "structpw__impl__metadata.html", null ],
     [ "pw_impl_metadata_events", "structpw__impl__metadata__events.html", "structpw__impl__metadata__events" ],
+    [ "pw_impl_module", "structpw__impl__module.html", null ],
     [ "pw_impl_module_events", "structpw__impl__module__events.html", "structpw__impl__module__events" ],
+    [ "pw_impl_node", "structpw__impl__node.html", null ],
     [ "pw_impl_node_events", "structpw__impl__node__events.html", "structpw__impl__node__events" ],
+    [ "pw_impl_port", "structpw__impl__port.html", null ],
     [ "pw_impl_port_events", "structpw__impl__port__events.html", "structpw__impl__port__events" ],
+    [ "pw_link", "structpw__link.html", null ],
     [ "pw_link_events", "structpw__link__events.html", "structpw__link__events" ],
     [ "pw_link_info", "structpw__link__info.html", "structpw__link__info" ],
     [ "pw_link_methods", "structpw__link__methods.html", "structpw__link__methods" ],
     [ "pw_loop", "structpw__loop.html", "structpw__loop" ],
+    [ "pw_main_loop", "structpw__main__loop.html", null ],
     [ "pw_main_loop_events", "structpw__main__loop__events.html", "structpw__main__loop__events" ],
     [ "pw_map", "structpw__map.html", "structpw__map" ],
-    [ "pw_map_item", "unionpw__map__item.html", "unionpw__map__item" ],
     [ "pw_map_range", "structpw__map__range.html", "structpw__map__range" ],
     [ "pw_memblock", "structpw__memblock.html", "structpw__memblock" ],
+    [ "pw_memchunk", "structpw__memchunk.html", null ],
     [ "pw_memmap", "structpw__memmap.html", "structpw__memmap" ],
-    [ "pw_mempool", "structpw__mempool.html", "structpw__mempool" ],
+    [ "pw_mempool", "structpw__mempool.html", null ],
     [ "pw_mempool_events", "structpw__mempool__events.html", "structpw__mempool__events" ],
+    [ "pw_metadata", "structpw__metadata.html", null ],
+    [ "pw_metadata_events", "structpw__metadata__events.html", "structpw__metadata__events" ],
+    [ "pw_metadata_methods", "structpw__metadata__methods.html", "structpw__metadata__methods" ],
+    [ "pw_module", "structpw__module.html", null ],
     [ "pw_module_events", "structpw__module__events.html", "structpw__module__events" ],
     [ "pw_module_info", "structpw__module__info.html", "structpw__module__info" ],
     [ "pw_module_methods", "structpw__module__methods.html", "structpw__module__methods" ],
+    [ "pw_node", "structpw__node.html", null ],
     [ "pw_node_events", "structpw__node__events.html", "structpw__node__events" ],
     [ "pw_node_info", "structpw__node__info.html", "structpw__node__info" ],
     [ "pw_node_methods", "structpw__node__methods.html", "structpw__node__methods" ],
     [ "pw_permission", "structpw__permission.html", "structpw__permission" ],
+    [ "pw_port", "structpw__port.html", null ],
     [ "pw_port_events", "structpw__port__events.html", "structpw__port__events" ],
     [ "pw_port_info", "structpw__port__info.html", "structpw__port__info" ],
     [ "pw_port_methods", "structpw__port__methods.html", "structpw__port__methods" ],
+    [ "pw_profiler", "structpw__profiler.html", null ],
+    [ "pw_profiler_events", "structpw__profiler__events.html", "structpw__profiler__events" ],
+    [ "pw_profiler_methods", "structpw__profiler__methods.html", "structpw__profiler__methods" ],
     [ "pw_properties", "structpw__properties.html", "structpw__properties" ],
+    [ "pw_protocol", "structpw__protocol.html", null ],
     [ "pw_protocol_client", "structpw__protocol__client.html", "structpw__protocol__client" ],
     [ "pw_protocol_events", "structpw__protocol__events.html", "structpw__protocol__events" ],
     [ "pw_protocol_implementation", "structpw__protocol__implementation.html", "structpw__protocol__implementation" ],
     [ "pw_protocol_marshal", "structpw__protocol__marshal.html", "structpw__protocol__marshal" ],
+    [ "pw_protocol_native_demarshal", "structpw__protocol__native__demarshal.html", "structpw__protocol__native__demarshal" ],
+    [ "pw_protocol_native_ext", "structpw__protocol__native__ext.html", "structpw__protocol__native__ext" ],
+    [ "pw_protocol_native_message", "structpw__protocol__native__message.html", "structpw__protocol__native__message" ],
     [ "pw_protocol_server", "structpw__protocol__server.html", "structpw__protocol__server" ],
+    [ "pw_proxy", "structpw__proxy.html", null ],
     [ "pw_proxy_events", "structpw__proxy__events.html", "structpw__proxy__events" ],
+    [ "pw_registry", "structpw__registry.html", null ],
     [ "pw_registry_events", "structpw__registry__events.html", "structpw__registry__events" ],
     [ "pw_registry_methods", "structpw__registry__methods.html", "structpw__registry__methods" ],
+    [ "pw_resource", "structpw__resource.html", null ],
     [ "pw_resource_events", "structpw__resource__events.html", "structpw__resource__events" ],
+    [ "pw_session", "structpw__session.html", null ],
+    [ "pw_session_events", "structpw__session__events.html", "structpw__session__events" ],
+    [ "pw_session_info", "structpw__session__info.html", "structpw__session__info" ],
+    [ "pw_session_methods", "structpw__session__methods.html", "structpw__session__methods" ],
+    [ "pw_stream", "structpw__stream.html", null ],
     [ "pw_stream_control", "structpw__stream__control.html", "structpw__stream__control" ],
     [ "pw_stream_events", "structpw__stream__events.html", "structpw__stream__events" ],
+    [ "pw_thread_loop", "structpw__thread__loop.html", null ],
     [ "pw_thread_loop_events", "structpw__thread__loop__events.html", "structpw__thread__loop__events" ],
     [ "pw_time", "structpw__time.html", "structpw__time" ],
+    [ "pw_work_queue", "structpw__work__queue.html", null ],
     [ "pwtest_context", "structpwtest__context.html", null ],
     [ "pwtest_spa_plugin", "structpwtest__spa__plugin.html", "structpwtest__spa__plugin" ],
     [ "pwtest_suite", "structpwtest__suite.html", null ],
     [ "pwtest_test", "structpwtest__test.html", null ],
-    [ "queue", "structqueue.html", "structqueue" ],
-    [ "registry", "structregistry.html", "structregistry" ],
-    [ "registry_event", "structregistry__event.html", "structregistry__event" ],
-    [ "resource_data", "structresource__data.html", "structresource__data" ],
-    [ "result_device_params_data", "structresult__device__params__data.html", "structresult__device__params__data" ],
-    [ "result_node_params_data", "structresult__node__params__data.html", "structresult__node__params__data" ],
-    [ "result_port_params_data", "structresult__port__params__data.html", "structresult__port__params__data" ],
-    [ "route", "structroute.html", "structroute" ],
-    [ "route_info", "structroute__info.html", "structroute__info" ],
-    [ "server", "structserver.html", "structserver" ],
+    [ "spa_audio_aec", "structspa__audio__aec.html", "structspa__audio__aec" ],
+    [ "spa_audio_aec_events", "structspa__audio__aec__events.html", "structspa__audio__aec__events" ],
+    [ "spa_audio_aec_info", "structspa__audio__aec__info.html", "structspa__audio__aec__info" ],
+    [ "spa_audio_aec_methods", "structspa__audio__aec__methods.html", "structspa__audio__aec__methods" ],
     [ "spa_audio_info", "structspa__audio__info.html", "structspa__audio__info" ],
+    [ "spa_audio_info_dsd", "structspa__audio__info__dsd.html", "structspa__audio__info__dsd" ],
     [ "spa_audio_info_dsp", "structspa__audio__info__dsp.html", "structspa__audio__info__dsp" ],
+    [ "spa_audio_info_iec958", "structspa__audio__info__iec958.html", "structspa__audio__info__iec958" ],
     [ "spa_audio_info_raw", "structspa__audio__info__raw.html", "structspa__audio__info__raw" ],
     [ "spa_audio_layout_info", "structspa__audio__layout__info.html", "structspa__audio__layout__info" ],
     [ "spa_buffer", "structspa__buffer.html", "structspa__buffer" ],
@@ -183,6 +201,7 @@ var annotated_dup =
     [ "spa_list", "structspa__list.html", "structspa__list" ],
     [ "spa_log", "structspa__log.html", "structspa__log" ],
     [ "spa_log_methods", "structspa__log__methods.html", "structspa__log__methods" ],
+    [ "spa_log_topic", "structspa__log__topic.html", "structspa__log__topic" ],
     [ "spa_loop", "structspa__loop.html", "structspa__loop" ],
     [ "spa_loop_control", "structspa__loop__control.html", "structspa__loop__control" ],
     [ "spa_loop_control_hooks", "structspa__loop__control__hooks.html", "structspa__loop__control__hooks" ],
@@ -203,6 +222,8 @@ var annotated_dup =
     [ "spa_node_info", "structspa__node__info.html", "structspa__node__info" ],
     [ "spa_node_methods", "structspa__node__methods.html", "structspa__node__methods" ],
     [ "spa_param_info", "structspa__param__info.html", "structspa__param__info" ],
+    [ "spa_plugin_loader", "structspa__plugin__loader.html", "structspa__plugin__loader" ],
+    [ "spa_plugin_loader_methods", "structspa__plugin__loader__methods.html", "structspa__plugin__loader__methods" ],
     [ "spa_pod", "structspa__pod.html", "structspa__pod" ],
     [ "spa_pod_array", "structspa__pod__array.html", "structspa__pod__array" ],
     [ "spa_pod_array_body", "structspa__pod__array__body.html", "structspa__pod__array__body" ],
@@ -251,6 +272,7 @@ var annotated_dup =
     [ "spa_support", "structspa__support.html", "structspa__support" ],
     [ "spa_system", "structspa__system.html", "structspa__system" ],
     [ "spa_system_methods", "structspa__system__methods.html", "structspa__system__methods" ],
+    [ "spa_thread", "structspa__thread.html", null ],
     [ "spa_thread_utils", "structspa__thread__utils.html", "structspa__thread__utils" ],
     [ "spa_thread_utils_methods", "structspa__thread__utils__methods.html", "structspa__thread__utils__methods" ],
     [ "spa_type_info", "structspa__type__info.html", "structspa__type__info" ],
@@ -259,11 +281,5 @@ var annotated_dup =
     [ "spa_video_info_dsp", "structspa__video__info__dsp.html", "structspa__video__info__dsp" ],
     [ "spa_video_info_h264", "structspa__video__info__h264.html", "structspa__video__info__h264" ],
     [ "spa_video_info_mjpg", "structspa__video__info__mjpg.html", "structspa__video__info__mjpg" ],
-    [ "spa_video_info_raw", "structspa__video__info__raw.html", "structspa__video__info__raw" ],
-    [ "stream", "structstream.html", "structstream" ],
-    [ "support", "structsupport.html", "structsupport" ],
-    [ "sync", "structsync.html", "structsync" ],
-    [ "thread", "structthread.html", "structthread" ],
-    [ "tunnel", "structtunnel.html", "structtunnel" ],
-    [ "tunnel_info", "structtunnel__info.html", "structtunnel__info" ]
+    [ "spa_video_info_raw", "structspa__video__info__raw.html", "structspa__video__info__raw" ]
 ];
\ No newline at end of file
